@@ -30,7 +30,7 @@ class TerminalRender(mistune.HTMLRenderer):
             return super().heading(header_text, 2)
         return super().heading(self._to_title(text), level)
 
-    def list(self, body, ordered, level, start=None):
+    def list(self, body, ordered, *args, **kwargs):
         """Rendering list tags like ``<ul>`` and ``<ol>``.
 
         :param body: body contents of the list.
@@ -39,9 +39,9 @@ class TerminalRender(mistune.HTMLRenderer):
         tag = "ul"
         if ordered:
             tag = "ol"
-        return "<%s>%s</%s>\n" % (tag, body, tag)
+        return "<{}>{}</{}>\n".format(tag, body, tag)
 
-    def list_item(self, text, level):
+    def list_item(self, text, *args):
         """Rendering list item snippet. Like ``<li>``."""
         return "<li> * %s</li>\n" % text
 
@@ -62,5 +62,5 @@ def replace_to_markdown_title(original):
 def render(text):
     replaced = replace_to_markdown_title(text)
     html_text = markdown_render(replaced)
-    logger.debug("[Document] {} ...".format(html_text)[:20])
+    logger.debug(f"[Document] {html_text} ..."[:20])
     return to_formatted_text(HTML(html_text))
