@@ -1,18 +1,20 @@
 import os
 import re
+from textwrap import dedent
+from unittest.mock import MagicMock, patch
+
+from packaging.version import parse as version_parse
+from prompt_toolkit.formatted_text import FormattedText
 import pytest
 import redis
-from unittest.mock import MagicMock, patch
-from textwrap import dedent
-
-from prompt_toolkit.formatted_text import FormattedText
 
 from iredis.client import Client
-from iredis.config import config, load_config_files
+from iredis.commands import command2syntax
 from iredis.completers import IRedisCompleter
+from iredis.config import config, load_config_files
 from iredis.entry import Rainbow, prompt_message
 from iredis.exceptions import NotSupport
-from iredis.commands import command2syntax
+
 from ..helpers import formatted_text_rematch
 
 
@@ -22,8 +24,12 @@ def completer():
 
 
 zset_type = "ziplist"
-if os.environ["REDIS_VERSION"] == "7":
+hash_type = "hashtable"
+list_type = "quicklist"
+if version_parse(os.environ["REDIS_VERSION"]) >= version_parse("7"):
     zset_type = "listpack"
+    hash_type = "listpack"
+    list_type = "listpack"
 
 
 @pytest.mark.parametrize(
@@ -36,7 +42,7 @@ if os.environ["REDIS_VERSION"] == "7":
     ],
 )
 def test_send_command(_input, command_name, expect_args):
-    client = Client("127.0.0.1", "6379", None)
+    client = Client("127.0.0.1", 6379, None)
     client.execute = MagicMock()
     next(client.send_command(_input, None))
     args, _ = client.execute.call_args
@@ -176,7 +182,7 @@ def test_not_retry_on_authentication_error(iredis_client, config):
 
 
 @pytest.mark.skipif(
-    "int(os.environ['REDIS_VERSION']) != 6",
+    "version_parse(os.environ['REDIS_VERSION']) != version_parse('6')",
     reason="""
 in redis7, it will not work if you:
 1. connect redis without password
@@ -209,7 +215,7 @@ def test_auto_select_db_and_auth_for_reconnect_only_6(iredis_client, config):
     )
 
 
-@pytest.mark.skipif("int(os.environ['REDIS_VERSION']) > 5")
+@pytest.mark.skipif("version_parse(os.environ['REDIS_VERSION']) > version_parse('5')")
 def test_auto_select_db_and_auth_for_reconnect_only_5(iredis_client, config):
     config.retry_times = 2
     config.raw = True
@@ -303,7 +309,7 @@ def test_peek_list_fetch_all(iredis_client, clean_redis):
         FormattedText(
             [
                 ("class:dockey", "key: "),
-                ("", r"list \(quicklist\)  mem: \d+ bytes, ttl: -1"),
+                ("", rf"list \({list_type}\)  mem: \d+ bytes, ttl: -1"),
                 ("", "\n"),
                 ("class:dockey", "llen: "),
                 ("", "5"),
@@ -351,7 +357,7 @@ def test_peek_set_fetch_part(iredis_client, clean_redis):
     peek_result = list(iredis_client.do_peek("myset"))
 
     assert peek_result[0][0] == ("class:dockey", "key: ")
-    assert peek_result[0][1][1].startswith("set (hashtable)  mem: 2")
+    assert peek_result[0][1][1].startswith(f"set ({hash_type})  mem: ")
 
 
 def test_peek_zset_fetch_all(iredis_client, clean_redis):
@@ -425,7 +431,7 @@ def test_peek_stream(iredis_client, clean_redis):
 
     assert peek_result[0][0] == ("class:dockey", "key: ")
     assert re.match(
-        r"stream \((stream|unknown)\)  mem: 6\d\d bytes, ttl: -1", peek_result[0][1][1]
+        r"stream \((stream|unknown)\)  mem: \d+ bytes, ttl: -1", peek_result[0][1][1]
     )
     assert peek_result[0][2:18] == FormattedText(
         [
@@ -550,23 +556,29 @@ def test_version_parse_for_auth(iredis_client):
     "info, version",
     [
         (
-            "# Server\r\nredis_version:df--128-NOTFOUND\r\n"
-            "redis_mode:standalone\r\narch_bits:64",
+            (
+                "# Server\r\nredis_version:df--128-NOTFOUND\r\n"
+                "redis_mode:standalone\r\narch_bits:64"
+            ),
             "df--128-NOTFOUND",
         ),
         (
-            "# Server\r\nredis_version:6.2.5\r\n"
-            "redis_git_sha1:00000000\r\n"
-            "redis_git_dirty:0\r\n"
-            "redis_build_id:915e5480613bc9b6\r\n"
-            "redis_mode:standalone ",
+            (
+                "# Server\r\nredis_version:6.2.5\r\n"
+                "redis_git_sha1:00000000\r\n"
+                "redis_git_dirty:0\r\n"
+                "redis_build_id:915e5480613bc9b6\r\n"
+                "redis_mode:standalone "
+            ),
             "6.2.5",
         ),
         (
-            "# Server\r\nredis_version:5.0.14.1\r\n"
-            "redis_git_sha1:00000000\r\nredis_git_dirty:0\r\n"
-            "redis_build_id:915e5480613bc9b6\r\n"
-            "redis_mode:standalone ",
+            (
+                "# Server\r\nredis_version:5.0.14.1\r\n"
+                "redis_git_sha1:00000000\r\nredis_git_dirty:0\r\n"
+                "redis_build_id:915e5480613bc9b6\r\n"
+                "redis_mode:standalone "
+            ),
             "5.0.14.1",
         ),
     ],
@@ -576,9 +588,10 @@ def test_version_path(info, version):
         mock_config.no_info = True
         mock_config.pager = "less"
         mock_config.version = "5.0.0"
+        mock_config.decode = "utf-8"
         with patch("iredis.client.Client.execute") as mock_execute:
             mock_execute.return_value = info
-            client = Client("127.0.0.1", "6379", None)
+            client = Client("127.0.0.1", 6379)
             client.get_server_info()
             assert mock_config.version == version
 
